@@ -10,10 +10,8 @@ consoleHandler.setFormatter(logFormatter)
 rootLogger.addHandler(consoleHandler)
 
 
-__version__ = "0.2.3"
+__version__ = "0.2.9"
 __DOWNLOAD_SERVER__ = 'https://public.ukp.informatik.tu-darmstadt.de/reimers/sentence-transformers/v0.2/'
-from .datasets import SentencesDataset, SentenceLabelDataset
-from .data_samplers import LabelSampler
 from .LoggingHandler import LoggingHandler
 from .SentenceTransformer import SentenceTransformer
 
