@@ -42,8 +42,11 @@ class EncoderLoader(object):
         config = json.load(open(os.path.join(model_dir, 'config.json')))
 
         device_check = DeviceCheck()
-        device = device_check.get_device_by_model(model_id) if use_gpu else 'cpu'
-        config['use_gpu'] = False if device == 'cpu' else True
+        device_name, device_ids = device_check.get_device_by_model(model_id, n_gpu=1 if use_gpu else 0)
+        device_name = '{}:{}'.format(device_name, device_ids[0]) if len(device_ids) == 1 else device_name
+
+        device = torch.device(device_name)
+        config['use_gpu'] = False if device_name == 'cpu' else True
         config['device'] = device
         config = Pack(config)
         if config.encoder_class == 'TransformerWrapper':
